require 'rails_helper'

RSpec.describe NestedPersonAttributeRenderer do
  let(:html) { described_class.new('Person', nested_value.to_json).render }
  subject { Capybara.string(html) }

  context 'with name' do
    let(:nested_value) { build(:dataset, :with_complex_person).complex_person.first }

    it 'generates the correct fields' do
      is_expected.to have_css('th', text: 'Person')

      is_expected.to have_css('div.row label', text: 'Name')
      is_expected.to have_css('div.row a', text: 'Anamika')

      is_expected.to have_css('div.row label', text: 'Affiliation')
      is_expected.to have_css('div.row', text: 'University')

      is_expected.to have_css('div.row label', text: 'Role')
      is_expected.to have_css('div.row', text: 'operator')

      is_expected.to have_css('div.row label', text: 'ORCID')
      is_expected.to have_css('div.row', text: '123456')
    end
  end

  context 'with first_name and last_name' do
    let(:nested_value) { { first_name: ['Foo'], last_name: ['Bar'] } }
    it 'generates the correct fields' do
      is_expected.to have_css('th', text: 'Person')
      is_expected.to have_css('div.row label', text: 'Name')
      is_expected.to have_css('div.row a', text: 'Foo Bar')
    end
  end
end
